#!/usr/bin/env bash

run_directory=$(dirname "$0")
user=$(whoami)

source "$run_directory/variables.conf"

if [ -f $run_directory/.disabled ]; then
  echo "Installation is disabled. Exiting..."
  exit 0
fi

echo "Copying Systemd units to system directory..."
if [[ $user != 'root' ]]; then
  sudo cp systemd-templates/cont-snap@.service /etc/systemd/system/
  sudo cp systemd-templates/conts-snap.service /etc/systemd/system/
  sudo sed -i -e "s:PH_DIRECTORY:$(pwd):g" /etc/systemd/system/conts-snap.service
  sudo cp systemd-templates/conts-snap.timer /etc/systemd/system/
  sudo cp systemd-templates/machines-start.timer /etc/systemd/system/
  if [ $docker -eq 1 ]; then
    sudo cp systemd-templates/docker-upgrade.service /etc/systemd/system/
    sudo sed -i -e "s:PH_DIRECTORY:$(pwd):g" /etc/systemd/system/docker-upgrade.service
    sudo cp systemd-templates/docker-upgrade.timer /etc/systemd/system/
  fi
else
  cp systemd-templates/cont-snap@.service /etc/systemd/system/
  cp systemd-templates/conts-snap.service /etc/systemd/system/
  sed -i -e "s:PH_DIRECTORY:$(pwd):g" /etc/systemd/system/conts-snap.service
  cp systemd-templates/conts-snap.timer /etc/systemd/system/
  cp systemd-templates/machines-start.timer /etc/systemd/system/
  if [ $docker -eq 1 ]; then
    cp systemd-templates/docker-upgrade.service /etc/systemd/system/
    sed -i -e "s:PH_DIRECTORY:$(pwd):g" /etc/systemd/system/docker-upgrade.service
    cp systemd-templates/docker-upgrade.timer /etc/systemd/system/
  fi
fi
echo "Reloading Systemd..."
if [[ $user != 'root' ]]; then
  sudo systemctl daemon-reload
else
  systemctl daemon-reload
fi
echo "Enabling timer(s) (not starting it, either do it manually or reboot)..."
if [[ $user != 'root' ]]; then
  sudo systemctl enable conts-snap.timer
  if [ $docker -eq 1 ]; then
    sudo systemctl enable docker-upgrade.timer
  fi
else
  systemctl enable conts-snap.timer
  if [ $docker -eq 1 ]; then
    systemctl enable docker-upgrade.timer
  fi
fi

echo "Finished install. Exiting..."
exit 0
